@@ -1,6 +1,6 @@
 # $Author: ddumont $
-# $Date: 2009-03-12 13:33:03 +0100 (Thu, 12 Mar 2009) $
-# $Revision: 893 $
+# $Date: 2009-03-31 13:41:21 +0200 (Tue, 31 Mar 2009) $
+# $Revision: 910 $
 
 #    Copyright (c) 2008 Dominique Dumont.
 #
@@ -32,7 +32,7 @@ use subs qw/menu_struct/ ;
 
 use Tk::NoteBook;
 
-$VERSION = sprintf "1.%04d", q$Revision: 893 $ =~ /(\d+)/;
+$VERSION = sprintf "1.%04d", q$Revision: 910 $ =~ /(\d+)/;
 
 Construct Tk::Widget 'ConfigModelCheckListEditor';
 
@@ -105,9 +105,7 @@ sub Populate {
 			-command => sub { $cw->store ( &$get_selected )},
 		      ) -> pack(-side => 'left') ;
 
-    $cw->add_help_frame() ;
-    $cw->add_help(class   => $leaf->parent->get_help) ;
-    $cw->add_help(element => $leaf->parent->get_help($leaf->element_name)) ;
+    $cw->add_summary_and_description($leaf) ;
     $cw->{value_help_widget} = $cw->add_help(value => '',1);
     $b_sub->() ;
 
